<?php

namespace App\Http\Controllers;

use App\Models\Isp;
use App\Models\Issue;
use App\Models\Malicious;
use App\Models\Reseller;
use App\Models\User;
use App\Models\Village;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Http\Request;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index(Request $request)
    {
        $is_admin = $is_operator = false;

        $user = User::find($request->user()->id);
        if($user->hasRole('Operator')){
            $is_operator = true;
        } else {
            $is_admin = true;
        }
        // if($user->hasRole('Operator')){
        //     if(!$user->has('isp')){
        //         abort(404);
        //     }
        //     $is_operator = true;
        //     $maliciouses    = $user->isp->maliciouses();
        //     $resellers      = new Reseller;

        //     $isp_id = $user->isp->id;
        //     $rank_villages  = Village::whereHas('resellers', function(Builder $query) use ($isp_id){
        //         $query->whereHas('maliciouses', function (Builder $query) use ($isp_id) {
        //             $query->where([
        //                 'status' => 'Accepted',
        //                 'isp_id' => $isp_id
        //             ]);
        //         });
        //     })->withCount([
        //         'resellers as count' => function(Builder $query) use ($isp_id){
        //             $query->whereHas('maliciouses', function (Builder $query) use ($isp_id) {
        //                 $query->where([
        //                     'status' => 'Accepted',
        //                     'isp_id' => $isp_id
        //                 ]);
        //             });
        //         }
        //     ]);
        //     $rank_issues  = Issue::whereHas('maliciouses',function(Builder $query) use ($isp_id){
        //         $query->where([
        //             'status' => 'Accepted',
        //             'isp_id' => $isp_id
        //         ]);
        //     })->withCount([
        //         'maliciouses as count' => function(Builder $query) use ($isp_id){
        //             $query->where([
        //                 'status' => 'Accepted',
        //                 'isp_id' => $isp_id
        //             ]);
        //         }
        //     ]);


        // } else {
            
            $maliciouses    = new Malicious;
            $resellers      = new Reseller;
            
            $rank_villages  = Village::has('resellers')->withCount('resellers as count');
            $rank_issues    = Issue::has('malicious_issues')->withCount(['malicious_issues as count' => function(Builder $query) {
                $query->whereRelation('maliciouses', 'status', 'Accepted');
            }]);
        //}

        $isp = new Isp;
        $rank_isp = Isp::select('*','legal_name as name')->has('maliciouses')->withCount([
            'maliciouses as count' => function (Builder $query) {
                $query->where('status', 'Accepted');
            },
        ])->orderBy('count','desc')->limit(10);
        $rank_villages->orderBy('count','desc')->limit(10);
        $rank_issues->orderBy('count','desc')->limit(10);


        $dashboard = (object)[
            'cards' => (object)[
                (object)[
                    'title' => 'Providers',
                    'count' => $isp->count(),
                    'link'  => route('isps.index'),
                    'show'  => $is_admin
                ],
                (object)[
                    'title' => 'Maliciouses',
                    'count' => $maliciouses->count(),
                    'link'  => route('maliciouses.index'),
                    'show'  => ($is_admin || $is_operator),
                ],
                (object)[
                    'title' => 'Resellers',
                    'count' => $resellers->count(),
                    'link'  => route('resellers.index'),
                    'show'  => ($is_admin || $is_operator),
                ]
            ],
            'ranks' => (object)[
                (object)[
                    'title' => 'Top 10 Providers',
                    'show'  => $is_admin,
                    'data'  => $rank_isp->get()
                ],
                (object)[
                    'title' => 'Top 10 Villages',
                    'show'  => ($is_admin || $is_operator),
                    'data'  => $rank_villages->get()
                ],
                (object)[
                    'title' => 'Top 10 Issues',
                    'show'  => ($is_admin || $is_operator),
                    'data'  => $rank_issues->get()
                ],
            ]
        ];
        return view('home', compact('dashboard'));
    }
}
