<?php

namespace App\Http\Controllers;

use App\Models\Isp;
use App\Http\Requests\StoreIspRequest;
use App\Http\Requests\UpdateIspRequest;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Storage;
use Yajra\DataTables\Facades\DataTables;

class IspController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if($request->ajax()){
            $model = Isp::query();
            return DataTables::of($model)->toJson();
        }
        return view('pages.isp.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('pages.isp.form');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(StoreIspRequest $request)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to created, please check your input'
        ];

        $input = $request->validated();
        $path = null;
        if($request->file('logo')){
            $path = $request->file('logo')->store('logo', 'public');
            $input['logo'] = $path;
        }

        $isp_data   = collect($input)->except(['user'])->toArray();
        $user_data  = [
            'name' => $isp_data['brand_name'] ?? 'Operator',
            'password' => bcrypt($input['user']['password']) 
        ];

        $isp = Isp::create($isp_data);
        if(!empty($isp) && $isp->user()->create($user_data)){
            $isp->refresh();
            $isp->user->syncRoles(['Operator']);
            $alert = [
                'type' => 'success',
                'message' => 'Data has been created'
            ];
            return redirect()->route('isps.index')->with([
                'alert' => json_decode(json_encode($alert))
            ]);
        }
        return back()->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }

    /**
     * Display the specified resource.
     */
    public function show(Isp $isp)
    {
        return view('pages.isp.form', compact('isp'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Isp $isp)
    {
        return view('pages.isp.form', compact('isp'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(UpdateIspRequest $request, Isp $isp)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to updated'
        ];
        $input = $request->validated();

        $path = null;
        if($request->file('logo')){
            $path = $request->file('logo')->store('logo', 'public');
            $input['logo'] = $path;

            $old_logo = str($isp->logo)->replace(asset('/storage'), '');
            if(!empty($path) && Storage::disk('public')->exists($old_logo)){
                Storage::disk('public')->delete($old_logo);
            }
        }

        $user_data  = [
            'name'  => $input['brand_name'],
            'email' => $input['email'],
        ];

        $password = $input['user']['password'] ?? null;
        if(isset($password) && !empty($password)){
            $user_data['password'] = bcrypt($password);
        }

        if($isp->user()->update($user_data) && $isp->update($input)){
            $isp->refresh();
            $isp->user->syncRoles(['Operator']);
            $alert = [
                'type' => 'success',
                'message' => 'Data has been updated'
            ];
            return redirect()->route('isps.index')->with([
                'alert' => json_decode(json_encode($alert))
            ]);
        } else {
            if(!empty($path) && Storage::disk('public')->exists($path)){
                Storage::disk('public')->delete($path);
            }
        }

        return redirect()->route('isps.index')->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request, Isp $isp)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to deleted'
        ];
        if($isp->user()->delete() && $isp->delete()){
            $alert = [
                'type' => 'success',
                'message' => 'Data has been deleted'
            ];
        }
        if($request->ajax()){
            return new JsonResource($isp);
        }
        return redirect()->route('isps.index')->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }
}
