<?php

namespace App\Http\Controllers;

use App\Models\Issue;
use App\Http\Requests\StoreIssueRequest;
use App\Http\Requests\UpdateIssueRequest;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Yajra\DataTables\Facades\DataTables;

class IssueController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if($request->ajax()){
            $model = Issue::query();
            return DataTables::of($model)->toJson();
        }
        return view('pages.issue.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('pages.issue.form');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(StoreIssueRequest $request)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to created'
        ];
        $input = $request->validated();
        $model = Issue::create($input);
        if(!empty($model)){
            $alert = [
                'type' => 'success',
                'message' => 'Data has been created'
            ];
        }
        return redirect()->route('issues.index')->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }

    /**
     * Display the specified resource.
     */
    public function show(Issue $issue)
    {
        return view('pages.issue.form', compact('issue'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Issue $issue)
    {
        return view('pages.issue.form', compact('issue'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(UpdateIssueRequest $request, Issue $issue)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to updated'
        ];
        $input = $request->validated();
        $issue->update($input);
        if(!empty($model)){
            $alert = [
                'type' => 'success',
                'message' => 'Data has been updated'
            ];
        }
        return redirect()->route('issues.index')->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request, Issue $issue)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to deleted'
        ];
        if($issue->delete()){
            $alert = [
                'type' => 'success',
                'message' => 'Data has been deleted'
            ];
        }
        if($request->ajax()){
            return new JsonResource($issue);
        }
        return redirect()->route('issues.index')->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }
}
