<?php

namespace App\Http\Controllers\My;

use App\Http\Controllers\Controller;
use App\Http\Requests\My\Account\UpdateRequest;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class AccountController extends Controller
{
    public function show(){
        $user = User::find(auth()->user()->id);
        if($user->hasRole('Operator')){
            $isp = $user->isp;
            if(empty($isp)){
                abort(404);
            }
            return view('pages.my.account.isp-form', compact('isp'));
        } else {
            return view('pages.my.account.edit-account');
        }
        
    }

    public function update(Request $request){
        $alert = (object)[
            'message'   => 'Account failed to update',
            'type'      => 'danger'
        ];

        $user = User::find(auth()->user()->id);
        if($user->hasRole('Operator')){
            $alert = [
                'type' => 'danger',
                'message' => 'Data failed to updated'
            ];
            $isp = $user->isp;
            if(empty($isp)){
                abort(404);
            } else {
                $input = $request->validate([
                    'register_number' => 'required|unique:isps,register_number,' . $isp->id  . ',id',
                    'type'              => 'required',
                    'legal_name'        => 'required|string|max:125',
                    'brand_name'        => 'required|string|max:125',
                    'logo'              => 'nullable|image|max:2048',
                    'address'           => 'nullable|string|max:255',
                    'village_code'      => 'nullable|exists:villages,code',
                    'email'             => [
                        'required',
                        'email',
                        'unique:isps,email,
                        ' . $isp->id  . ',id',
                        'unique:users,email,' . $isp->user->id . ',id'
                    ],
                    'phone'             => 'nullable|string|max:64',
                    'fax'               => 'nullable|string|max:20',
                    'website'           => 'nullable|string|max:20',
                    'facebook'          => 'nullable|string|max:255',
                    'instagram'         => 'nullable|string|max:255',
                    'tiktok'            => 'nullable|string|max:255',
                    'user.password'     => 'nullable|string|min:6|max:32'
                ]);

                $path = null;
                if($request->file('logo')){
                    $path = $request->file('logo')->store('logo', 'public');
                    $input['logo'] = $path;
        
                    $old_logo = str($isp->logo)->replace(asset('/storage'), '');
                    if(!empty($path) && Storage::disk('public')->exists($old_logo)){
                        Storage::disk('public')->delete($old_logo);
                    }
                }
        
                $user_data  = [
                    'name'  => $input['brand_name'],
                    'email' => $input['email'],
                ];
        
                $password = $input['user']['password'] ?? null;
                if(isset($password) && !empty($password)){
                    $user_data['password'] = bcrypt($password);
                }
        
                if($isp->user()->update($user_data) && $isp->update($input)){
                    $alert = [
                        'type' => 'success',
                        'message' => 'Data has been updated'
                    ];
                } else {
                    if(!empty($path) && Storage::disk('public')->exists($path)){
                        Storage::disk('public')->delete($path);
                    }
                }
            }
            
        } else {
            $input  = $request->validate([
                'email' => 'required|min:4|max:40|unique:users,email,' . auth()->user()->id . ',id',
                'name'  => 'required|string|min:4|max:125'
            ]);
            $user   = User::find(auth()->user()->id);
            if($user->update($input)){
                $alert = [
                    'type' => 'success',
                    'message' => 'Data has been updated'
                ];
            }
        }
        return back()->with(['alert' => $alert]);
    }
}
