<?php

namespace App\Http\Controllers\My;

use App\Http\Controllers\Controller;
use App\Http\Requests\My\Account\Image\UploadRequest;
use App\Models\Customer;
use App\Models\Admin;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Storage;
use Intervention\Image\Facades\Image;

class AccountImageUploadController extends Controller
{
    /**
     * Handle the incoming request.
     */
    public function __invoke(UploadRequest $request)
    {
        $user = Admin::find(auth()->user()->id);
        $uploading = $request->hasFile('image');
        $uploading = $uploading && $request->file('image')->isValid();
        if($uploading){
            $path   = $request->file('image')->storePublicly('customers', 'public');
            $image  = Image::make(storage_path('app/public/' . $path))->fit(150);
            $canvas = Image::canvas(150, 150);
            $canvas->circle(150, 75, 75, function ($draw) {
                $draw->background('#000000');
            });
            $image->mask($canvas->encode('png', 90), true)->save();

            if(!empty($path)){
                if (Storage::disk('public')->exists($user->image ?? '')) {
                    Storage::disk('public')->delete($user->image ?? '');
                }
                $user->image = $path;
                $user->save();
            }
        }
        return new JsonResource($user);
    }
}
