<?php

namespace App\Http\Controllers;

use App\Models\Page;
use App\Http\Requests\StorePageRequest;
use App\Http\Requests\UpdatePageRequest;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Yajra\DataTables\Facades\DataTables;

class PageController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if($request->ajax()){
            $model = Page::query();
            return DataTables::of($model)->toJson();
        }
        return view('pages.page.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('pages.page.form');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(StorePageRequest $request)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to created'
        ];
        $input = $request->validated();
        $model = Page::create($input);
        if(!empty($model)){
            $alert = [
                'type' => 'success',
                'message' => 'Data has been created'
            ];
        }
        return redirect()->route('pages.index')->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }

    /**
     * Display the specified resource.
     */
    public function show(Page $page)
    {
        return view('pages.page.show', compact('page'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Page $page)
    {
        return view('pages.page.form', compact('page'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(UpdatePageRequest $request, Page $page)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to updated'
        ];
        $input = $request->validated();
        if($page->update($input)){
            $alert = [
                'type' => 'success',
                'message' => 'Data has been updated'
            ];
        }
        return redirect()->route('pages.index')->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request, Page $page)
    {
        $alert = [
            'type' => 'danger',
            'message' => 'Data failed to deleted'
        ];
        if($page->delete()){
            $alert = [
                'type' => 'success',
                'message' => 'Data has been deleted'
            ];
        }
        if($request->ajax()){
            return new JsonResource($page);
        }
        return redirect()->route('pages.index')->with([
            'alert' => json_decode(json_encode($alert))
        ]);
    }
}
