<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class StoreMaliciousRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return $this->user()->hasRole('Operator');
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array
    {
        return [
            'reseller.type'         => 'required',
            'reseller.nik'          => 'required_if:reseller.type,Personal|required_if:reseller.npwp,null',
            'reseller.npwp'         => 'required_if:reseller.type,Corporate|required_if:reseller.nik,null',
            'reseller.legal_name'   => 'required|string|max:125',
            'reseller.brand_name'   => 'required|string|max:125',
            'reseller.address'      => 'nullable|string|max:255',
            'reseller.village_code' => 'required|exists:villages,code',
            'reseller.email'        => 'nullable|email',
            'reseller.phone'        => 'nullable|string|max:64',
            'reseller.social_media.facebook'    => 'nullable|string|max:255',
            'reseller.social_media.instagram'   => 'nullable|string|max:255',
            'reseller.social_media.tiktok'      => 'nullable|string|max:255',
            'reseller.map.long'     => 'nullable|string',
            'reseller.map.lat'      => 'nullable|string',
            'reseller.pic.name'     => 'nullable|string',
            'reseller.pic.photo'    => 'nullable|image|max:2048',
            'reseller.pic.email'    => 'nullable|string',
            'reseller.pic.phone'    => 'nullable|string',
            'title'                 => 'required|string',
            'description'           => 'nullable|string',
            'issues'                => 'nullable|array',
            'issues.*'              => 'nullable|string',
            'attachments'           => 'nullable|array',
            'attachments.*'         => 'nullable|file|max:2048',
        ];
    }
}
