<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Support\Facades\Storage;
use App\Models\Village;

class Isp extends Model
{
    use HasFactory;

    protected $fillable = [
        'register_number',
        'type',
        'legal_name',
        'brand_name',
        'logo',
        'address',
        'village_code',
        'email',
        'phone',
        'fax',
        'website',
        'facebook',
        'instagram',
        'tiktok',
    ];

    protected $appends = ['full_address'];

    protected function logo(): Attribute {
        return Attribute::make(
            get: function(string|null $value){
                $url = 'https://placehold.co/150x150';
                if(!empty($value) && Storage::disk('public')->exists($value)){
                    $url = asset(Storage::url($value));
                }
                return $url;
            },
        );
    }

    protected function getFullAddressAttribute() {
        $address    = [];
        $meta       = (object)[];
        if(isset($this->address) && !empty($this->address)){
            array_push($address, $this->address);
        }
        if(isset($this->village) && !empty($this->village)){
            if(isset($this->village->name) && !empty($this->village->name)){
                $meta = !empty($this->village->meta) ? json_decode(json_encode($this->village->meta ?? [])) : $meta;
                array_push($address, $this->village->name);
            }
            if(isset($this->village->district->name) && !empty($this->village->district->name)){
                array_push($address, $this->village->district->name);
            }
            if(isset($this->village->district->city->name) && !empty($this->village->district->city->name)){
                array_push($address, $this->village->district->city->name);
            }
            if(isset($this->village->district->city->province->name) && !empty($this->village->district->city->province->name)){
                array_push($address, $this->village->district->city->province->name);
            }

        }
        $fulladdress = implode(', ', $address) . '. '. (isset($meta->pos) && !empty($meta->pos) ? $meta->pos: null);
        return $fulladdress;
    }

    public function village(): BelongsTo {
        return $this->belongsTo(Village::class, 'village_code', 'code');
    }

    public function maliciouses(): HasMany {
        return $this->hasMany(Malicious::class, 'isp_id', 'id');
    }

    public function user(): HasOne {
        return $this->hasOne(User::class, 'email', 'email');
    }
}
