<?php

namespace App\Models;

use App\Casts\Json;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\MorphMany;
use Illuminate\Support\Facades\Storage;

class Malicious extends Model
{
    use HasFactory;

    protected $fillable = ['isp_id','title','description','reseller', 'status', 'photo'];

    protected $casts = [
        'reseller' => Json::class,
    ];

    protected $appends = ['full_address'];

    protected function photo(): Attribute {
        return Attribute::make(
            get: function(string|null $value){
                $url = 'https://placehold.co/150x150';
                if(!empty($value) && Storage::disk('public')->exists($value)){
                    $url = asset(Storage::url($value));
                }
                return $url;
            },
        );
    }

    protected function getFullAddressAttribute() {
        $address    = [];
        $meta       = (object)[];
        if(isset($this->reseller->address) && !empty($this->reseller->address)){
            array_push($address, $this->reseller->address);
        }
        $village = Village::where('code', $this->reseller->village_code ?? null)->first();
        if(isset($village) && !empty($village)){
            if(isset($village->name) && !empty($village->name)){
                $meta = !empty($village->meta) ? json_decode(json_encode($village->meta ?? [])) : $meta;
                array_push($address, $village->name);
            }
            if(isset($village->district->name) && !empty($village->district->name)){
                array_push($address, $village->district->name);
            }
            if(isset($village->district->city->name) && !empty($village->district->city->name)){
                array_push($address, $village->district->city->name);
            }
            if(isset($village->district->city->province->name) && !empty($village->district->city->province->name)){
                array_push($address, $village->district->city->province->name);
            }

        }
        $fulladdress = implode(', ', $address) . '. '. (isset($meta->pos) && !empty($meta->pos) ? $meta->pos: null);
        return $fulladdress;
    }

    public function issues(): BelongsToMany {
        return $this->belongsToMany(Issue::class, 'malicious_issues', 'malicious_id', 'issue_id');
    }

    public function attachments(): MorphMany {
        return $this->morphMany(Attachment::class, 'attachmentable');
    }

    public function isp(): BelongsTo
    {
        return $this->belongsTo(Isp::class, 'isp_id', 'id');
    }

    public function reseller(): BelongsTo
    {
        return $this->belongsTo(Reseller::class, 'reseller_id', 'id');
    }
}
