<?php

namespace App\Models;

use App\Casts\Json;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Laravolt\Indonesia\Models\Village;

class Reseller extends Model
{
    use HasFactory;

    protected $casts = [
        'social_media'  => Json::class,
        'pic'           => Json::class,
        'map'           => Json::class,
    ];

    protected $fillable = [
        'type',
        'nik',
        'npwp',
        'legal_name',
        'brand_name',
        'logo',
        'address',
        'village_code',
        'social_media',
        'pic',
        'map'
    ];

    protected $appends = ['full_address'];

    protected function getFullAddressAttribute() {
        $address    = [];
        $meta       = (object)[];
        if(isset($this->address) && !empty($this->address)){
            array_push($address, $this->address);
        }
        if(isset($this->village) && !empty($this->village)){
            if(isset($this->village->name) && !empty($this->village->name)){
                $meta = !empty($this->village->meta) ? json_decode(json_encode($this->village->meta ?? [])) : $meta;
                array_push($address, $this->village->name);
            }
            if(isset($this->village->district->name) && !empty($this->village->district->name)){
                array_push($address, $this->village->district->name);
            }
            if(isset($this->village->district->city->name) && !empty($this->village->district->city->name)){
                array_push($address, $this->village->district->city->name);
            }
            if(isset($this->village->district->city->province->name) && !empty($this->village->district->city->province->name)){
                array_push($address, $this->village->district->city->province->name);
            }

        }
        $fulladdress = implode(', ', $address) . '. '. (isset($meta->pos) && !empty($meta->pos) ? $meta->pos: null);
        return $fulladdress;
    }

    public function village(): BelongsTo {
        return $this->belongsTo(Village::class, 'village_code', 'code');
    }

    public function maliciouses(): HasMany {
        return $this->hasMany(Malicious::class, 'reseller_id', 'id');
    }
}
