@extends('layouts.app')

@section('content')
<div class="container">
    <div class="d-flex justify-content-between align-items-center mb-1">
        <div>
            <h1 class="mb-0 fw-bolder">Form @if (request()->routeIs('maliciouses.edit')) Edit @else Create @endif{{ str('malicious')->ucfirst() }}</h1>
        </div>
        <div>
            <a href="{{ route('maliciouses.index') }}" class="btn btn-light shadow">
                <i class="fa fa-fw fa-arrow-left"></i> Back To Lists
            </a>
        </div>
    </div>
    <form method="POST" action="{{ request()->routeIs('maliciouses.edit') ? route('maliciouses.update', ($malicious ?? null)) : route('maliciouses.store') }}" enctype="multipart/form-data">
        @csrf
        @method(request()->routeIs('maliciouses.edit') ? 'PUT' : 'POST')
        <div class="card shadow">
            <div class="card-body">
                <div class="row">
                    <div class="col-md-7">
                        <h4 class="fw-bolder text-center">Reseller</h4>
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input id="reseller-legal_name" name="reseller[legal_name]" 
                                        class="form-control @error('reseller.legal_name') is-invalid @enderror" 
                                        value="{{ old('reseller.legal_name', ($malicious->reseller->legal_name ?? null)) }}"
                                    />
                                    <label for="reseller-legal_name">Legal Name</label>
                                    @error('reseller.legal_name')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="brand_name" name="reseller[brand_name]" 
                                        class="form-control @error('reseller.brand_name') is-invalid @enderror" 
                                        value="{{ old('reseller.brand_name', ($malicious->reseller->brand_name ?? null)) }}"
                                    />
                                    <label for="reseller-brand_name">Brand Name</label>
                                    @error('reseller.brand_name')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <select id="reseller-type" name="reseller[type]" class="form-select @error('reseller.type') is-invalid @enderror">
                                        <option value="Corporate" @selected('Corporate' == old('reseller.type', ($malicious->reseller->type ?? 'Corporate')) )>Corporate</option>
                                        <option value="Personal" @selected('Personal' == old('reseller.type', ($malicious->reseller->type ?? null)) )>Personal</option>
                                    </select>
                                    <label for="reseller-type">Type</label>
                                    @error('reseller.type')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-nik" name="reseller[nik]" 
                                        class="form-control @error('reseller.nik') is-invalid @enderror" 
                                        value="{{ old('reseller.nik', ($malicious->reseller->nik ?? null)) }}"
                                    />
                                    <label for="reseller-nik">NIK</label>
                                    @error('reseller.nik')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-npwp" name="reseller[npwp]" 
                                        class="form-control @error('reseller.npwp') is-invalid @enderror" 
                                        value="{{ old('reseller.npwp', ($malicious->reseller->npwp ?? null)) }}"
                                    />
                                    <label for="reseller-npwp">NPWP</label>
                                    @error('reseller.npwp')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-email" name="reseller[email]" 
                                        class="form-control @error('reseller.email') is-invalid @enderror" 
                                        value="{{ old('reseller.email', ($malicious->reseller->email ?? null)) }}"
                                    />
                                    <label for="reseller-email">Email</label>
                                    @error('reseller.email')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                
                                <div class="form-floating mb-3">
                                    <input id="reseller-phone" name="reseller[phone]" 
                                        class="form-control @error('reseller.phone') is-invalid @enderror" 
                                        value="{{ old('reseller.phone', ($malicious->reseller->phone ?? null)) }}"
                                    />
                                    <label for="reseller-phone">Phone</label>
                                    @error('reseller.phone')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                
                                <div class="form-floating mb-3">
                                    <input id="reseller-social-media-facebook" name="reseller[social_media][facebook]" 
                                        class="form-control @error('reseller.social_media.facebook') is-invalid @enderror" 
                                        value="{{ old('reseller.social_media.facebook', ($malicious->reseller->social_media->facebook ?? null)) }}"
                                    />
                                    <label for="reseller-social-media-facebook">Facebook</label>
                                    @error('reseller.social_media.facebook')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                
                                <div class="form-floating mb-3">
                                    <input id="reseller-social-media-instagram" name="reseller[social_media][instagram]" 
                                        class="form-control @error('reseller.social_media.instagram') is-invalid @enderror" 
                                        value="{{ old('reseller.social_media.instagram', ($malicious->reseller->social_media->instagram ?? null)) }}"
                                    />
                                    <label for="reseller-social-media-instagram">Instagram</label>
                                    @error('reseller.social_media.instagram')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-social-media-tiktok" name="reseller[social_media][tiktok]" 
                                        class="form-control @error('reseller.social_media.tiktok') is-invalid @enderror" 
                                        value="{{ old('reseller.social_media.tiktok', ($malicious->reseller->social_media->tiktok ?? null)) }}"
                                    />
                                    <label for="reseller-social-media-tiktok">Tiktok</label>
                                    @error('reseller.social_media.tiktok')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <textarea id="reseller-address" name="reseller[address]" rows="3"
                                        class="form-control @error('reseller.address') is-invalid @enderror" 
                                    >{{ old('reseller.address', ($malicious->reseller->address ?? null)) }}</textarea>
                                    <label for="reseller-address">Address</label>
                                    @error('reseller.address')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <select id="province_code" class="form-select @error('province_code') is-invalid @enderror">
                                    @if (isset($village->district->city->province->id))
                                        <option value="{{ $village->district->city->province->code }}" selected>{{ $village->district->city->province->name }}</option>
                                    @endif
                                    </select>
                                    <label for="province_code">Province</label>
                                    @error('province_code')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <select id="city_code" class="form-select @error('city_code') is-invalid @enderror">
                                    @if (isset($village->district->city->id))
                                        <option value="{{ $village->district->city->code }}" selected>{{ $village->district->city->name }}</option>
                                    @endif
                                    </select>
                                    <label for="city_code">City</label>
                                    @error('city_code')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <select id="district_code" class="form-select @error('district_code') is-invalid @enderror">
                                    @if (isset($village->district->id))
                                        <option value="{{ $village->district->code }}" selected>{{ $village->district->name }}</option>
                                    @endif
                                    </select>
                                    <label for="district_code">District</label>
                                    @error('district_code')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <select id="village_code" name="reseller[village_code]" class="form-select @error('reseller.village_code') is-invalid @enderror">
                                    @if (isset($village->id))
                                        <option value="{{ $village->code }}" selected>{{ $village->name }}</option>
                                    @endif
                                    </select>
                                    <label for="village_code">Village</label>
                                    @error('reseller.village_code')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-map-long" name="reseller[map][long]" 
                                        class="form-control @error('reseller.map.long') is-invalid @enderror" 
                                        value="{{ old('reseller.map.long', ($malicious->reseller->map->long ?? null)) }}"
                                    />
                                    <label for="reseller-map-long">Map (Longitude)</label>
                                    @error('reseller.map.long')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-map-lat" name="reseller[map][lat]" 
                                        class="form-control @error('reseller.map.lat') is-invalid @enderror" 
                                        value="{{ old('reseller.map.lat', ($malicious->reseller->map->lat ?? null)) }}"
                                    />
                                    <label for="reseller-map-lat">Map (Latitude)</label>
                                    @error('reseller.map.lat')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-pic-name" name="reseller[pic][name]" 
                                        class="form-control @error('reseller.pic.name') is-invalid @enderror" 
                                        value="{{ old('reseller.pic.name', ($malicious->reseller->pic->name ?? null)) }}"
                                    />
                                    <label for="reseller-pic-name">PIC Name</label>
                                    @error('reseller.pic.name')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-pic-phone" name="reseller[pic][phone]" 
                                        class="form-control @error('reseller.pic.phone') is-invalid @enderror" 
                                        value="{{ old('reseller.pic.phone', ($malicious->reseller->pic->phone ?? null)) }}"
                                    />
                                    <label for="reseller-pic-phone">PIC Phone</label>
                                    @error('reseller.pic.phone')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="form-floating mb-3">
                                    <input id="reseller-pic-email" name="reseller[pic][email]" 
                                        class="form-control @error('reseller.pic.email') is-invalid @enderror" 
                                        value="{{ old('reseller.pic.email', ($malicious->reseller->pic->email ?? null)) }}"
                                    />
                                    <label for="reseller-pic-email">PIC Email</label>
                                    @error('reseller.pic.email')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-5">
                        <div class="mb-3 text-center">
                            <label for="reseller-pic-photo" class="mb-2">
                                <span class="text-center">PIC Photo</span>
                                <div class="text-center" >
                                    <img id="preview-input-reseller-pic-photo" src="{{ old('reseller.pic.photo', ($isp->reseller->pic->photo ?? 'https://placehold.co/150x150')) }}" class="img-fluid img-thumbnail" style="max-width:150px; max-height:150px;">
                                </div>
                            </label>
                            <input id="reseller-pic-photo" name="reseller[pic][photo]" type="file"
                                class="form-control @error('reseller.pic.photo') is-invalid @enderror with-image-preview" 
                                value="" data-target="#preview-input-reseller-pic-photo"
                            />
                            @error('reseller.pic.photo')
                            <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        <h4 class="fw-bolder text-center">Malicious</h4>
                        <div class="form-floating mb-3">
                            
                            <input id="title" name="title" placeholder="Title"
                                class="form-control @error('title') is-invalid @enderror" 
                                value="{{ old('title', ($malicious->title ?? null)) }}"
                            />
                            <label for="title">Title</label>
                            @error('title')
                            <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        <div class="form-floating mb-3">
                            <textarea id="description" name="description" style="height:125px"
                                class="form-control @error('description') is-invalid @enderror"
                            >{{ old('description', ($malicious->description ?? null)) }}</textarea>
                            <label for="description">Description</label>
                            @error('description')
                            <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        <div class="mb-3">
                            <label for="issues">Issues</label>
                            <select id="issues" name="issues[]" class="form-select @error('issues') is-invalid @enderror" multiple>
                            @if (isset($malicious->issues))
                                @foreach ($malicious->issues as $issue)
                                <option value="{{ $issue->name }}" selected>{{ $issue->name }}</option>
                                @endforeach
                            @endif
                            </select>
                            
                            @error('issues')
                            <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        <div class="mb-3">
                            <label for="attachments">Attachments</label>
                            <input id="attachments" name="attachments[]" type="file" multiple="true"
                                class="form-control @error('attachments') is-invalid @enderror" 
                                value="{{ old('attachments', ($malicious->attachments ?? null)) }}"
                            />
                            @error('attachments')
                            <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                        @if (isset($malicious->attachments))
                        <ol class="list-group">
                            @foreach ($malicious->attachments as $attachment)
                            <li class="list-group-item d-flex justify-content-between align-items-start">
                                <div class="me-auto">
                                    <div class="fw-bold">{{ $attachment->filename }}</div>
                                    Size : {{ Number::fileSize($attachment->size) }} 
                                </div>
                                <button type="button" class="btn btn-light shadow btn-file-delete" 
                                    data-action="{{ 
                                        route('maliciouses.attachments.destroy', [
                                            'malicious' => $malicious,
                                            'attachment' => $attachment
                                        ]) 
                                    }}">
                                    <i class="fa fa-trash"></i>
                                </button>
                            </li>
                            @endforeach
                        </ol>
                        @endif
                    </div>
                </div>
                <div class="text-end">
                    <button type="submit" class="btn btn-primary">
                        <i class="fa fa-fw fa-save"></i> Save
                    </button>
                </div>
            </div>
        </div>
    </form>
</div>
@endsection

@push('css')
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/css/select2.min.css" integrity="sha512-nMNlpuaDPrqlEls3IX/Q56H36qvBASwb3ipuo3MxeWbsQB1881ox0cRv7UPTgBlriqoynt35KjEwgGUeUXIPnw==" crossorigin="anonymous" referrerpolicy="no-referrer" />
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/select2-bootstrap-5-theme/1.3.0/select2-bootstrap-5-theme.min.css" integrity="sha512-z/90a5SWiu4MWVelb5+ny7sAayYUfMmdXKEAbpj27PfdkamNdyI3hcjxPxkOPbrXoKIm7r9V2mElt5f1OtVhqA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/easy-autocomplete/1.3.5/easy-autocomplete.min.css" integrity="sha512-TsNN9S3X3jnaUdLd+JpyR5yVSBvW9M6ruKKqJl5XiBpuzzyIMcBavigTAHaH50MJudhv5XIkXMOwBL7TbhXThQ==" crossorigin="anonymous" referrerpolicy="no-referrer" />
@endpush

@push('js')
<script src="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/js/select2.full.min.js" integrity="sha512-RtZU3AyMVArmHLiW0suEZ9McadTdegwbgtiQl5Qqo9kunkVg1ofwueXD8/8wv3Af8jkME3DDe3yLfR8HSJfT2g==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/easy-autocomplete/1.3.5/jquery.easy-autocomplete.min.js" integrity="sha512-Z/2pIbAzFuLlc7WIt/xifag7As7GuTqoBbLsVTgut69QynAIOclmweT6o7pkxVoGGfLcmPJKn/lnxyMNKBAKgg==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script>
$(()=>{
    'use strict'
    $.fn.select2.defaults.set("theme", "bootstrap-5");
    $.fn.select2.defaults.set("width", "100%");
    
    const 
        selectProvince  = $(`#province_code`).select2({
            placeholder: 'Select Province',
            allowClear: true,
            ajax : {
                url : `{{ route('indonesia.provinces') }}`,
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        //obj.id      = obj.code;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            }
        }),
        selectCity      = $(`#city_code`).select2({
            placeholder: 'Select City',
            allowClear: true,
            ajax : {
                url : `{{ route('indonesia.cities') }}`,
                data: function (params) {
                    return $.extend({},params,{
                        filter : {
                            province_code : selectProvince.val()
                        }
                    });
                },
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        //obj.id      = obj.code;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            }
        }),
        selectDistrict  = $(`#district_code`).select2({
            placeholder: 'Select District',
            allowClear: true,
            ajax : {
                url : `{{ route('indonesia.districts') }}`,
                data: function (params) {
                    return $.extend({},params,{
                        filter : {
                            city_code : selectCity.val()
                        }
                    });
                },
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        //obj.id      = obj.code;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            }
        }),
        selectVillage   = $(`#village_code`).select2({
            placeholder: 'Select Village',
            allowClear: true,
            ajax : {
                url : `{{ route('indonesia.villages') }}`,
                data: function (params) {
                    return $.extend({},params,{
                        filter : {
                            district_code : selectDistrict.val()
                        }
                    });
                },
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        //obj.id      = obj.code;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            }
        }),
        selectIssue     = $(`#issues`).select2({
            tags: true,
            tokenSeparators: [','],
            placeholder: 'Select Issue',
            allowClear: true,
            multiple: true,
            ajax : {
                url : `{{ route('resources.issues') }}`,
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        obj.id      = obj.name;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            },
            createTag: function (params) {
                var term = $.trim(params.term);

                if (term === '') {
                    return null;
                }
                return {
                    id: term,
                    text: term
                }
            }
        });

        selectProvince.on({
            change(e){
                selectCity.val(null).trigger('change');
            }
        });
        selectCity.on({
            change(e){
                selectDistrict.val(null).trigger('change');
            }
        });
        selectDistrict.on({
            change(e){
                selectVillage.val(null).trigger('change');
            }
        });

    $('.with-image-preview').on({
        change(event){
            let imageElement    = $(`${$(event.target).attr('data-target')}`);
            let files           =  event.target.files;
            if (files && files[0]) {
                let file            = files[0];
                let reader          = new FileReader();
                reader.onload = (e) => {
                    imageElement.attr('src', e.target.result);
                };
                reader.readAsDataURL(file);
            }
        }
    });

    $('button.btn-file-delete').click((e)=>{
        e.preventDefault();
        e.stopPropagation();
        let li  = $(e.currentTarget).closest('li');
        let url = $(e.currentTarget).attr('data-action');
        $.post(url,{
            _method : 'DELETE',
            _token : `{{ csrf_token() }}`
        },(response)=>{
            createAlert(response.alert.message, {
                type : response.alert.type
            });
            if(response.alert.type == 'success'){
                li.remove();
            }
        },'json');
    });

    
});
</script>
@endpush