@extends('layouts.app')

@section('content')
<div class="container">
    <div class="d-flex justify-content-between align-items-center mb-1">
        <div>
            <h1 class="mb-0 fw-bolder">{{ str('malicious')->plural()->ucfirst() }}</h1>
        </div>
        @role('Operator')
        <div>
            <a href="{{ route('maliciouses.create') }}" class="btn btn-light shadow">
                <i class="fa fa-fw fa-plus"></i> Create
            </a>
        </div>
        @endrole
    </div>
    <div class="card shadow">
        <div class="card-body">
            <div class="table-responsive">
                <table id="table" class="table align-middle w-100" width="100%">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Title</th>
                            <th>Reseller</th>
                            <th>Reseller Brand Name</th>
                            <th>ISP </th>
                            <th>ISP Brand Name</th>
                            <th>Status</th>
                            <th></th>
                        </tr>
                    </thead>
                    <tbody></tbody>
                </table>
            </div>

        </div>
    </div>
</div>
@endsection

@push('css')
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/datatables.net-bs5/1.13.8/dataTables.bootstrap5.min.css" integrity="sha512-TYucTg2DTKx05NRJKSS3IoVrDPfhuNYCw30zPRFOYgE1OD1j2VQQ+iCZj2mG8vNcXStFGdV+1XBLOWSij+P/0w==" crossorigin="anonymous" referrerpolicy="no-referrer" />    
@endpush

@push('js')
<script src="https://cdnjs.cloudflare.com/ajax/libs/datatables/1.10.21/js/jquery.dataTables.min.js" integrity="sha512-BkpSL20WETFylMrcirBahHfSnY++H2O1W+UnEEO4yNIl+jI2+zowyoGJpbtk6bx97fBXf++WJHSSK2MV4ghPcg==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/datatables.net-bs5/1.13.8/dataTables.bootstrap5.min.js" integrity="sha512-zw34c1fnMeY29qzodeC+GGKfyQQ7hN+a9yjGnIAZbkPPn/Xeh8Z46uea/fjq5Mwsp4bxvGKfJrTNnh/GdIZJ1g==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
<script>
$(()=>{
    'use strict'
    $('#table').DataTable({
        serverSide: true,
        ajax: {
            url: `{{ route('maliciouses.index') }}`
        },
        order: [[0, 'desc']],
        columns: [
            { 
                data: 'id',
                width: '40px',
            },
            { 
                data: 'title',
                render(title, type, row, meta){
                    return `<a class="fw-bolder" href="{{ route('maliciouses.index') }}/${row.id}">${title}</a>`;
                }
            },
            { 
                data:'reseller',
                name:'reseller.legal_name',
                render(reseller, type, row, meta){
                    return `<p class="m-0 lh-1">
                        <strong>${reseller.brand_name}</strong><br/>
                        <small class="text-muted">${reseller.legal_name}</small>
                    </p>`;
                }
            
            },
            { data:'isp.brand_name', visible:false },
            { 
                data:'isp',
                name:'isp.legal_name',
                render(isp, type, row, meta){
                    return `<p class="m-0 lh-1">
                        <strong>${isp.brand_name}</strong><br/>
                        <small class="text-muted">${isp.legal_name}</small>
                    </p>`;
                }
            
            },
            { data:'isp.brand_name', visible:false },
            { data:'status' },
            { 
                data:'id',
                className: 'text-end',
                width: '40px',
                render(data, type, row, meta){
                    return `<div class="dropdown dropstart">
                        <button class="btn btn-sm btn-light shadow" data-bs-toggle="dropdown"><i class="fa fa-fw fa-ellipsis-vertical"></i></button>
                        <ul class="dropdown-menu dropdown-menu-end">
                            @role('Operator')
                            <li><a class="dropdown-item" href="{{ route('maliciouses.index') }}/${data}/edit">Edit</a></li>
                            <li><a class="dropdown-item dt-row-delete" href="{{ route('maliciouses.index') }}/${data}">Delete</a></li> 
                            @endrole
                            @role('Admin')
                            <li><a class="dropdown-item dt-row-delete" href="{{ route('maliciouses.index') }}/${data}">Delete</a></li> 
                            @endrole
                        </ul>
                    </div>`;
                } 
            }
        ],
        rowCallback(row){
            let api = this.api();
            $(row).find('.dt-row-delete').click(function(e){
                e.preventDefault();
                let url = $(this).attr('href');
                Swal.fire({
                    title   : "Are you sure ?",
                    text    : "Data can't restore after deleted!",
                    icon    : "warning",
                    showCancelButton: true,
                    confirmButtonColor: "#DD6B55",
                    confirmButtonText: "Yes, Delete!",
                    cancelButtonText: "No, Cancel",
                }).then((result) => {
                    if (result.value) {
                        $.ajax({
                            url: url,
                            type: "DELETE",
                            data: {
                                _token  : '{{ csrf_token() }}',
                                _method : 'DELETE'
                            },
                            error   : function(response){
                                createAlert('Data failed to delete', { type:'danger' });
                            },
                            success : function(response) {
                                createAlert('Data has been updated');
                                api.ajax.reload(null, false);
                            }
                        });
                    }
                });
            });
        }
    });
})
</script>
@endpush
