@extends('layouts.app')

@section('content')
<div class="container">
    <div class="d-flex justify-content-between align-items-center mb-1">
        <div>
            <h1 class="mb-0 fw-bolder">Malicious #{{ $malicious->id }}</h1>
        </div>
        <div>
            <a href="{{ route('maliciouses.index') }}" class="btn btn-light shadow">
                <i class="fa fa-fw fa-arrow-left"></i> Back To Lists
            </a>
            @role('Operator')
            @if ($malicious->status == 'Draft')
            <a href="{{ route('maliciouses.edit', $malicious) }}" class="btn btn-primary shadow">
                <i class="fa fa-fw fa-edit"></i> Edit
            </a>                
            @endif
            @endrole
        </div>
    </div>
    <div class="card shadow">
        <div class="card-body">
            <div class="row">
                <div class="col-md-5">
                    <h4 class="fw-bolder">Reseller Profile</h4>
                    <dl class="row">
                        <dt class="col-sm-3">Type</dt>
                        <dd class="col-sm-9">{{ $malicious->reseller->type ?? '-' }}</dd>
                      
                        <dt class="col-sm-3">NIK</dt>
                        <dd class="col-sm-9">{{ $malicious->reseller->nik ?? '-' }}</dd>
                      
                        <dt class="col-sm-3">NPWP</dt>
                        <dd class="col-sm-9">{{ $malicious->reseller->npwp ?? '-' }}</dd>
                      
                        <dt class="col-sm-3">Legal Name</dt>
                        <dd class="col-sm-9">{{ $malicious->reseller->legal_name ?? '-' }}</dd>

                        <dt class="col-sm-3">Brand Name</dt>
                        <dd class="col-sm-9">{{ $malicious->reseller->brand_name ?? '-' }}</dd>

                        <dt class="col-sm-3">Email</dt>
                        <dd class="col-sm-9">{{ $malicious->reseller->email ?? '-' }}</dd>

                        <dt class="col-sm-3">Phone</dt>
                        <dd class="col-sm-9">{{ $malicious->reseller->phone ?? '-' }}</dd>
    
                        <dt class="col-sm-3">Address</dt>
                        <dd class="col-sm-9">{{ $malicious->full_address ?? '-' }}</dd>
                    
                        @if (isset($malicious->reseller->social_media))
                            @foreach ($malicious->reseller->social_media as $name => $url)
                            <dt class="col-sm-3">{{ str($name)->ucfirst() }}</dt>
                            <dd class="col-sm-9">
                                <a href="{{ $url }}" target="_blank">{{ $url ?? '-' }}</a>
                            </dd>
                            @endforeach
                        @endif
                    </dl>
                    <div id="map" class="w-100" style="height:300px;"></div>
                </div>
                <div class="col-md-7">
                    <h4 class="fw-bolder">PIC</h4>
                    <dl class="row">
                        @if (isset($malicious->reseller->pic))
                            @foreach ($malicious->reseller->pic as $key => $value)
                                <dt class="col-sm-3">{{ str($key)->ucfirst() }}</dt>
                                <dd class="col-sm-9">
                                    @if ($key == 'photo')
                                    <img src="{{ asset('storage/' . $value) }}" class="img-fluid img-thumbnail" style="max-width:200px;" />
                                    @else
                                    {{ $value ?? '-' }}
                                    @endif
                                </dd>
                            @endforeach
                        @endif
                    </dl>
                    <h4 class="fw-bolder">Malicious</h4>
                    <dl class="row">
                        <dt class="col-sm-3">Title</dt>
                        <dd class="col-sm-9">{{ $malicious->title ?? '-' }}</dd>

                        <dt class="col-sm-3">Issues</dt>
                        <dd class="col-sm-9">
                            @if (isset($malicious->issues))
                            @foreach ($malicious->issues as $issue)
                                <label class="badge bg-primary">{{ $issue->name }}</label>
                            @endforeach
                            @endif    
                        </dd>

                        <dt class="col-sm-3">Description</dt>
                        <dd class="col-sm-9">{!! nl2br($malicious->description ?? '-')!!}</dd>

                        <dt class="col-sm-3">Attachments</dt>
                        <dd class="col-sm-9">
                            @if (isset($malicious->attachments))
                            <ol class="list-group">
                                @foreach ($malicious->attachments as $attachment)
                                <li class="list-group-item d-flex justify-content-between align-items-start">
                                    <div class="me-auto">
                                        <div class="fw-bold">{{ $attachment->filename }}</div>
                                        Size : {{ Number::fileSize($attachment->size) }} 
                                    </div>
                                    <a class="btn btn-light shadow btn-file-delete" 
                                        href="{{ route('maliciouses.attachments.show', [
                                            'malicious' => $malicious,
                                            'attachment' => $attachment
                                        ]) }}">
                                        <i class="fa fa-download"></i>
                                    </a>
                                </li>
                                @endforeach
                            </ol>
                            @endif 
                        </dd>

                        <dt class="col-sm-3">Status</dt>
                        <dd class="col-sm-9">
                            <div class="d-flex justify-content-between">
                                <div>{{ $malicious->status }}</div>
                                <div>
                                    <div class="d-flex">
                                        @role('Operator')
                                            @if ($malicious->status == 'Draft')
                                            <div class="col">
                                                <form method="POST" action="{{ route('maliciouses.requested', $malicious) }}">
                                                    @csrf
                                                    <button class="btn btn-primary">Send Request</button>
                                                </form>
                                            </div>
                                            @endif
                                        @endrole
                                        @role('Admin')
                                            @if ($malicious->status == 'Requested')
                                            <div class="col me-3">
                                                <form method="POST" action="{{ route('maliciouses.accepted', $malicious) }}">
                                                    @csrf
                                                    <button class="btn btn-primary">Accepted</button>
                                                </form>
                                            </div>
                                            <div class="col">
                                                <form method="POST" action="{{ route('maliciouses.rejected', $malicious) }}">
                                                    @csrf
                                                    <button class="btn btn-danger">Rejected</button>
                                                </form>
                                            </div>
                                            @endif
                                        @endrole
                                    </div>
                                </div>
                            </div>
                            
                        </dd>
                    </dl>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@push('css')
<link rel="stylesheet" href="https://unpkg.com/leaflet@1.9.4/dist/leaflet.css" />
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/css/select2.min.css" integrity="sha512-nMNlpuaDPrqlEls3IX/Q56H36qvBASwb3ipuo3MxeWbsQB1881ox0cRv7UPTgBlriqoynt35KjEwgGUeUXIPnw==" crossorigin="anonymous" referrerpolicy="no-referrer" />
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/select2-bootstrap-5-theme/1.3.0/select2-bootstrap-5-theme.min.css" integrity="sha512-z/90a5SWiu4MWVelb5+ny7sAayYUfMmdXKEAbpj27PfdkamNdyI3hcjxPxkOPbrXoKIm7r9V2mElt5f1OtVhqA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
@endpush

@push('js')
<script src="https://unpkg.com/leaflet@1.9.4/dist/leaflet.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/js/select2.full.min.js" integrity="sha512-RtZU3AyMVArmHLiW0suEZ9McadTdegwbgtiQl5Qqo9kunkVg1ofwueXD8/8wv3Af8jkME3DDe3yLfR8HSJfT2g==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script>
$(()=>{
    'use strict'
    $.fn.select2.defaults.set("theme", "bootstrap-5");
    $.fn.select2.defaults.set("width", "100%");
    const 
        selectProvince  = $(`#province_code`).select2({
            placeholder: 'Select Province',
            allowClear: true,
            ajax : {
                url : `{{ route('indonesia.provinces') }}`,
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        //obj.id      = obj.code;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            }
        }),
        selectCity      = $(`#city_code`).select2({
            placeholder: 'Select City',
            allowClear: true,
            ajax : {
                url : `{{ route('indonesia.cities') }}`,
                data: function (params) {
                    return $.extend({},params,{
                        filter : {
                            province_code : selectProvince.val()
                        }
                    });
                },
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        //obj.id      = obj.code;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            }
        }),
        selectDistrict  = $(`#district_code`).select2({
            placeholder: 'Select District',
            allowClear: true,
            ajax : {
                url : `{{ route('indonesia.districts') }}`,
                data: function (params) {
                    return $.extend({},params,{
                        filter : {
                            city_code : selectCity.val()
                        }
                    });
                },
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        //obj.id      = obj.code;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            }
        }),
        selectVillage   = $(`#village_code`).select2({
            placeholder: 'Select Village',
            allowClear: true,
            ajax : {
                url : `{{ route('indonesia.villages') }}`,
                data: function (params) {
                    return $.extend({},params,{
                        filter : {
                            district_code : selectDistrict.val()
                        }
                    });
                },
                dataType: `json`,
                processResults: function (response) {
                    let results = $.map(response.data, function (obj) {
                        //obj.id      = obj.code;
                        obj.text    = obj.text || obj.name;
                        return obj;
                    });
                    return {
                        results: results,
                        pagination: {
                            more: (response.links.next != '' && response.links.next != null && response.links.next != undefined) 
                        }
                    };
                }
            }
        });

        selectProvince.on({
            change(e){
                selectCity.val(null).trigger('change');
            }
        });
        selectCity.on({
            change(e){
                selectDistrict.val(null).trigger('change');
            }
        });
        selectDistrict.on({
            change(e){
                selectVillage.val(null).trigger('change');
            }
        });

    $('.with-image-preview').on({
        change(event){
            let imageElement    = $(`${$(event.target).attr('data-target')}`);
            let files           =  event.target.files;
            if (files && files[0]) {
                let file            = files[0];
                let reader          = new FileReader();
                reader.onload = (e) => {
                    imageElement.attr('src', e.target.result);
                };
                reader.readAsDataURL(file);
            }
        }
    });

    var map = L.map('map').setView([{{ $malicious->reseller->map->lat ?? null }},{{ $malicious->reseller->map->long ?? null }}], 15);
    L.tileLayer('https://tile.openstreetmap.org/{z}/{x}/{y}.png', {
        maxZoom: 25,
        attribution: '&copy; <a href="http://www.openstreetmap.org/copyright">OpenStreetMap</a>'
    }).addTo(map);
    var marker = L.marker([{{ $malicious->reseller->map->lat ?? null }},{{ $malicious->reseller->map->long ?? null }}]).addTo(map);
});
</script>
@endpush