@extends('layouts.app')

@section('content')
<div class="container">
    <div class="d-flex justify-content-between align-items-center mb-1">
        <div>
            <h1 class="mb-0 fw-bolder">Form @if (request()->routeIs('pages.edit')) Edit @else Create @endif{{ str('page')->singular()->ucfirst() }}</h1>
        </div>
        <div>
            <a href="{{ route('pages.index') }}" class="btn btn-light shadow">
                <i class="fa fa-fw fa-arrow-left"></i> Back To Lists
            </a>
        </div>
    </div>
    <div class="row justify-content-center">
        <div class="col-md-8">
            <form method="POST" action="{{ request()->routeIs('pages.edit') ? route('pages.update', ($page ?? null)) : route('pages.store') }}">
                @csrf
                @method(request()->routeIs('pages.edit') ? 'PUT' : 'POST')
                <div class="card shadow">
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-9">
                                <div class="form-floating mb-3">
                                    <input id="title" name="title" 
                                        class="form-control @error('title') is-invalid @enderror" 
                                        value="{{ old('title', ($page->title ?? null)) }}"
                                        placeholder="title"
                                    />
                                    <label for="title">title</label>
                                    @error('title')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-floating mb-3">
                                    <select id="status" name="status" class="form-control @error('status') is-invalid @enderror" placeholder="status">
                                        <option value="0" @checked(0 == old('status', ($page->status ?? 0)))>Draft</option>
                                        <option value="1" @checked(1 == old('status', ($page->status ?? 0))) >Publish</option>
                                    </select>
                                    <label for="status">status</label>
                                    @error('status')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                            </div>
                            <div class="mb-3">
                                <textarea id="editor" name="content" class="form-control @error('content') is-invalid @enderror">{!! old('content', ($page->content ?? null)) !!}</textarea>
                                @error('content')
                                <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                        <div class="text-end">
                            <button type="submit" class="btn btn-primary">
                                <i class="fa fa-fw fa-save"></i> Save
                            </button>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
</div>
@endsection

@push('js')
<script src="{{ asset('statics/vendor/tinymce/tinymce.min.js') }}"></script>
<script>
    tinymce.init({
        selector: 'textarea#editor',
        menubar: false
    });
</script>
@endpush