<?php

use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Auth::routes();

Route::get('page/{page:slug}', [App\Http\Controllers\PageController::class,'show'])->name('page');

Route::middleware(['auth'])->group(function () {
    Route::get('/', [App\Http\Controllers\HomeController::class, 'index'])->name('home');
    Route::resource('pages', App\Http\Controllers\PageController::class)->except('show');

    Route::prefix('my')->name('my.')->group(function(){
        Route::get('account/edit', [App\Http\Controllers\My\AccountController::class, 'show'])->name('account.edit');
        Route::post('account/edit', [App\Http\Controllers\My\AccountController::class, 'update'])->name('account.update');
        Route::post('account/image', App\Http\Controllers\My\AccountImageUploadController::class)->name('account.image.upload');
        Route::get('account/password', [App\Http\Controllers\My\AccountPasswordController::class, 'change'])->name('account.password.change');
        Route::post('account/password', [App\Http\Controllers\My\AccountPasswordController::class, 'update'])->name('account.password.update');
    });

    Route::resource('issues', App\Http\Controllers\IssueController::class)->except(['show']);
    Route::resource('isps', App\Http\Controllers\IspController::class)->except(['show']);
    Route::resource('maliciouses.attachments', App\Http\Controllers\MaliciousAttachmentController::class)->parameters([
        'maliciouses' => 'malicious'
    ])->only(['show','destroy']);
    Route::post('maliciouses/{malicious:id}/requested', [App\Http\Controllers\MaliciousController::class, 'requested'])
        ->name('maliciouses.requested');
    Route::post('maliciouses/{malicious:id}/accepted', [App\Http\Controllers\MaliciousController::class, 'accepted'])
        ->name('maliciouses.accepted');
    Route::post('maliciouses/{malicious:id}/rejected', [App\Http\Controllers\MaliciousController::class, 'rejected'])
        ->name('maliciouses.rejected');
    Route::resource('maliciouses', App\Http\Controllers\MaliciousController::class)->parameters([
        'maliciouses' => 'malicious'
    ]);
    Route::resource('resellers', App\Http\Controllers\ResellerController::class);

    Route::get('resources/issues', [App\Http\Controllers\Api\IssueController::class, 'index'])->name('resources.issues');
    Route::get('resources/indonesia/provinces', [App\Http\Controllers\Api\IndonesiaController::class, 'provinces'])->name('indonesia.provinces');
    Route::get('resources/indonesia/cities', [App\Http\Controllers\Api\IndonesiaController::class, 'cities'])->name('indonesia.cities');
    Route::get('resources/indonesia/districts', [App\Http\Controllers\Api\IndonesiaController::class, 'districts'])->name('indonesia.districts');
    Route::get('resources/indonesia/villages', [App\Http\Controllers\Api\IndonesiaController::class, 'villages'])->name('indonesia.villages');

    Route::get('settings', [App\Http\Controllers\SettingController::class, 'edit'])->name('settings.edit');
    Route::post('settings', [App\Http\Controllers\SettingController::class, 'update'])->name('settings.update');

});